@@ -9,10 +9,4 @@ ADMIN_COMMAND_PERMISSION = 'admin'
          help='make the bot shutdown')
 async def cmd_shutdown(msg: Message, *args):
     await msg.reply('bot shutting down...')
-    stop_all_tasks()
-
-    for seconds_left in range(10, 0, -1):
-        print(f'giving running tasks time to stop, closing in {seconds_left} seconds...')
-        await asyncio.sleep(1)
-
     get_bot().shutdown()
